@@ -24,6 +24,7 @@
 
 import asyncio
 import codecs
+import datetime
 import json
 import logging
 import os
@@ -60,6 +61,8 @@ duoStopUnpair = "08000000000000000000000000000000000000000000"
 duoRemotePair = "0D0006010000000000000000000000000000yyyyyy01"
 
 
+MIN_MESSAGE_INTERVAL_MILLIS = 50
+
 def refresh_serial_connection(function):
     def new_funtion(*args, **kwargs):
         self = args[0]
@@ -451,6 +454,7 @@ class DuofernStickThreaded(DuofernStick, threading.Thread):
         # DuofernStick.__init__(self, device, system_code, config_file_json, duofern_parser)
         self.serial_connection = serial.Serial(self.port, baudrate=115200, timeout=1)
         self.running = False
+        self.last_send = datetime.datetime.now()
 
     def _read_answer(self, some_string):  # ReadAnswer
         """read an answer..."""
@@ -553,6 +557,7 @@ class DuofernStickThreaded(DuofernStick, threading.Thread):
     @refresh_serial_connection
     def _simple_write(self, string_to_write):  # SimpleWrite
         """Just write data"""
+        self.last_send = datetime.datetime.now()
         logger.debug("writing  {}".format(string_to_write))
         hex_to_write = string_to_write.replace(" ", '')
         if self.recording:
@@ -567,10 +572,8 @@ class DuofernStickThreaded(DuofernStick, threading.Thread):
     def command(self, *args, **kwargs):
         if self.recording:
             with open(self.record_filename, "a") as recorder:
-                write("sending_command {} {}\n".format(args,kwargs))
-
-        loop = asyncio.get_event_loop()
-        loop.run_until_complete(self.duofern_parser.set(*args, **kwargs))
+                recorder.write("sending_command {} {}\n".format(args,kwargs))
+        self.duofern_parser.set(*args, **kwargs)
 
     def add_serial_and_send(self, msg):
         message = msg.replace("zzzzzz", "6f" + self.system_code)
@@ -588,16 +591,16 @@ class DuofernStickThreaded(DuofernStick, threading.Thread):
             try:
                 in_data = hex(self.serial_connection.read(22))
             except TypeError:
-                pass
+                continue
             if len(in_data) == 44:
-                if in_data != duoACK:
-                    self._simple_write(duoACK)
                 try:
                     self.process_message(in_data)
                 except Exception as exc:
                     logger.exception(exc)
+                if in_data != duoACK:
+                    self._simple_write(duoACK)
             self.serial_connection.timeout = 1
-            if len(self.write_queue) > 0:
+            if (len(self.write_queue) > 0) and ((datetime.datetime.now() - self.last_send) >= datetime.timedelta(milliseconds=MIN_MESSAGE_INTERVAL_MILLIS)):
                 self.handle_write_queue()
 
     def stop(self):
